# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "actual_node_count": "actualNodeCount",
    "api_endpoint": "apiEndpoint",
    "auto_scale": "autoScale",
    "bucket_domain_name": "bucketDomainName",
    "certificate_chain": "certificateChain",
    "certificate_id": "certificateId",
    "cluster_id": "clusterId",
    "cluster_subnet": "clusterSubnet",
    "cors_rules": "corsRules",
    "created_at": "createdAt",
    "custom_domain": "customDomain",
    "db_name": "dbName",
    "droplet_id": "dropletId",
    "droplet_ids": "dropletIds",
    "droplet_tag": "dropletTag",
    "enable_proxy_protocol": "enableProxyProtocol",
    "eviction_policy": "evictionPolicy",
    "filesystem_label": "filesystemLabel",
    "filesystem_type": "filesystemType",
    "force_destroy": "forceDestroy",
    "forwarding_rules": "forwardingRules",
    "inbound_rules": "inboundRules",
    "initial_filesystem_label": "initialFilesystemLabel",
    "initial_filesystem_type": "initialFilesystemType",
    "ip_address": "ipAddress",
    "ipv4_address": "ipv4Address",
    "ipv4_address_private": "ipv4AddressPrivate",
    "ipv6_address": "ipv6Address",
    "is_default": "isDefault",
    "kube_configs": "kubeConfigs",
    "leaf_certificate": "leafCertificate",
    "maintenance_windows": "maintenanceWindows",
    "max_nodes": "maxNodes",
    "min_disk_size": "minDiskSize",
    "min_nodes": "minNodes",
    "mysql_auth_plugin": "mysqlAuthPlugin",
    "node_count": "nodeCount",
    "node_pool": "nodePool",
    "not_after": "notAfter",
    "outbound_rules": "outboundRules",
    "owner_id": "ownerId",
    "owner_uuid": "ownerUuid",
    "pending_changes": "pendingChanges",
    "price_hourly": "priceHourly",
    "price_monthly": "priceMonthly",
    "private_host": "privateHost",
    "private_key": "privateKey",
    "private_networking": "privateNetworking",
    "private_uri": "privateUri",
    "public_key": "publicKey",
    "redirect_http_to_https": "redirectHttpToHttps",
    "resize_disk": "resizeDisk",
    "service_subnet": "serviceSubnet",
    "sha1_fingerprint": "sha1Fingerprint",
    "snapshot_id": "snapshotId",
    "spaces_access_id": "spacesAccessId",
    "spaces_secret_key": "spacesSecretKey",
    "sql_mode": "sqlMode",
    "ssh_keys": "sshKeys",
    "sticky_sessions": "stickySessions",
    "updated_at": "updatedAt",
    "user_data": "userData",
    "volume_id": "volumeId",
    "volume_ids": "volumeIds",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "actualNodeCount": "actual_node_count",
    "apiEndpoint": "api_endpoint",
    "autoScale": "auto_scale",
    "bucketDomainName": "bucket_domain_name",
    "certificateChain": "certificate_chain",
    "certificateId": "certificate_id",
    "clusterId": "cluster_id",
    "clusterSubnet": "cluster_subnet",
    "corsRules": "cors_rules",
    "createdAt": "created_at",
    "customDomain": "custom_domain",
    "dbName": "db_name",
    "dropletId": "droplet_id",
    "dropletIds": "droplet_ids",
    "dropletTag": "droplet_tag",
    "enableProxyProtocol": "enable_proxy_protocol",
    "evictionPolicy": "eviction_policy",
    "filesystemLabel": "filesystem_label",
    "filesystemType": "filesystem_type",
    "forceDestroy": "force_destroy",
    "forwardingRules": "forwarding_rules",
    "inboundRules": "inbound_rules",
    "initialFilesystemLabel": "initial_filesystem_label",
    "initialFilesystemType": "initial_filesystem_type",
    "ipAddress": "ip_address",
    "ipv4Address": "ipv4_address",
    "ipv4AddressPrivate": "ipv4_address_private",
    "ipv6Address": "ipv6_address",
    "isDefault": "is_default",
    "kubeConfigs": "kube_configs",
    "leafCertificate": "leaf_certificate",
    "maintenanceWindows": "maintenance_windows",
    "maxNodes": "max_nodes",
    "minDiskSize": "min_disk_size",
    "minNodes": "min_nodes",
    "mysqlAuthPlugin": "mysql_auth_plugin",
    "nodeCount": "node_count",
    "nodePool": "node_pool",
    "notAfter": "not_after",
    "outboundRules": "outbound_rules",
    "ownerId": "owner_id",
    "ownerUuid": "owner_uuid",
    "pendingChanges": "pending_changes",
    "priceHourly": "price_hourly",
    "priceMonthly": "price_monthly",
    "privateHost": "private_host",
    "privateKey": "private_key",
    "privateNetworking": "private_networking",
    "privateUri": "private_uri",
    "publicKey": "public_key",
    "redirectHttpToHttps": "redirect_http_to_https",
    "resizeDisk": "resize_disk",
    "serviceSubnet": "service_subnet",
    "sha1Fingerprint": "sha1_fingerprint",
    "snapshotId": "snapshot_id",
    "spacesAccessId": "spaces_access_id",
    "spacesSecretKey": "spaces_secret_key",
    "sqlMode": "sql_mode",
    "sshKeys": "ssh_keys",
    "stickySessions": "sticky_sessions",
    "updatedAt": "updated_at",
    "userData": "user_data",
    "volumeId": "volume_id",
    "volumeIds": "volume_ids",
}
